from pwnlib.constants.constant import Constant

__NR_exit = Constant('__NR_exit',1)
__NR_fork = Constant('__NR_fork',2)
__NR_read = Constant('__NR_read',3)
__NR_write = Constant('__NR_write',4)
__NR_open = Constant('__NR_open',5)
__NR_close = Constant('__NR_close',6)
__NR_wait4 = Constant('__NR_wait4',7)
__NR_creat = Constant('__NR_creat',8)
__NR_link = Constant('__NR_link',9)
__NR_unlink = Constant('__NR_unlink',10)
__NR_execv = Constant('__NR_execv',11)
__NR_chdir = Constant('__NR_chdir',12)
__NR_chown = Constant('__NR_chown',13)
__NR_mknod = Constant('__NR_mknod',14)
__NR_chmod = Constant('__NR_chmod',15)
__NR_lchown = Constant('__NR_lchown',16)
__NR_brk = Constant('__NR_brk',17)
__NR_perfctr = Constant('__NR_perfctr',18)
__NR_lseek = Constant('__NR_lseek',19)
__NR_getpid = Constant('__NR_getpid',20)
__NR_capget = Constant('__NR_capget',21)
__NR_capset = Constant('__NR_capset',22)
__NR_setuid = Constant('__NR_setuid',23)
__NR_getuid = Constant('__NR_getuid',24)
__NR_ptrace = Constant('__NR_ptrace',26)
__NR_alarm = Constant('__NR_alarm',27)
__NR_sigaltstack = Constant('__NR_sigaltstack',28)
__NR_pause = Constant('__NR_pause',29)
__NR_utime = Constant('__NR_utime',30)
__NR_lchown32 = Constant('__NR_lchown32',31)
__NR_fchown32 = Constant('__NR_fchown32',32)
__NR_access = Constant('__NR_access',33)
__NR_nice = Constant('__NR_nice',34)
__NR_chown32 = Constant('__NR_chown32',35)
__NR_sync = Constant('__NR_sync',36)
__NR_kill = Constant('__NR_kill',37)
__NR_stat = Constant('__NR_stat',38)
__NR_sendfile = Constant('__NR_sendfile',39)
__NR_lstat = Constant('__NR_lstat',40)
__NR_dup = Constant('__NR_dup',41)
__NR_pipe = Constant('__NR_pipe',42)
__NR_times = Constant('__NR_times',43)
__NR_getuid32 = Constant('__NR_getuid32',44)
__NR_umount2 = Constant('__NR_umount2',45)
__NR_setgid = Constant('__NR_setgid',46)
__NR_getgid = Constant('__NR_getgid',47)
__NR_signal = Constant('__NR_signal',48)
__NR_geteuid = Constant('__NR_geteuid',49)
__NR_getegid = Constant('__NR_getegid',50)
__NR_acct = Constant('__NR_acct',51)
__NR_getgid32 = Constant('__NR_getgid32',53)
__NR_ioctl = Constant('__NR_ioctl',54)
__NR_reboot = Constant('__NR_reboot',55)
__NR_mmap2 = Constant('__NR_mmap2',56)
__NR_symlink = Constant('__NR_symlink',57)
__NR_readlink = Constant('__NR_readlink',58)
__NR_execve = Constant('__NR_execve',59)
__NR_umask = Constant('__NR_umask',60)
__NR_chroot = Constant('__NR_chroot',61)
__NR_fstat = Constant('__NR_fstat',62)
__NR_fstat64 = Constant('__NR_fstat64',63)
__NR_getpagesize = Constant('__NR_getpagesize',64)
__NR_msync = Constant('__NR_msync',65)
__NR_vfork = Constant('__NR_vfork',66)
__NR_pread = Constant('__NR_pread',67)
__NR_pwrite = Constant('__NR_pwrite',68)
__NR_geteuid32 = Constant('__NR_geteuid32',69)
__NR_getegid32 = Constant('__NR_getegid32',70)
__NR_mmap = Constant('__NR_mmap',71)
__NR_setreuid32 = Constant('__NR_setreuid32',72)
__NR_munmap = Constant('__NR_munmap',73)
__NR_mprotect = Constant('__NR_mprotect',74)
__NR_madvise = Constant('__NR_madvise',75)
__NR_vhangup = Constant('__NR_vhangup',76)
__NR_truncate64 = Constant('__NR_truncate64',77)
__NR_mincore = Constant('__NR_mincore',78)
__NR_getgroups = Constant('__NR_getgroups',79)
__NR_setgroups = Constant('__NR_setgroups',80)
__NR_getpgrp = Constant('__NR_getpgrp',81)
__NR_setgroups32 = Constant('__NR_setgroups32',82)
__NR_setitimer = Constant('__NR_setitimer',83)
__NR_ftruncate64 = Constant('__NR_ftruncate64',84)
__NR_swapon = Constant('__NR_swapon',85)
__NR_getitimer = Constant('__NR_getitimer',86)
__NR_setuid32 = Constant('__NR_setuid32',87)
__NR_sethostname = Constant('__NR_sethostname',88)
__NR_setgid32 = Constant('__NR_setgid32',89)
__NR_dup2 = Constant('__NR_dup2',90)
__NR_setfsuid32 = Constant('__NR_setfsuid32',91)
__NR_fcntl = Constant('__NR_fcntl',92)
__NR_select = Constant('__NR_select',93)
__NR_setfsgid32 = Constant('__NR_setfsgid32',94)
__NR_fsync = Constant('__NR_fsync',95)
__NR_setpriority = Constant('__NR_setpriority',96)
__NR_socket = Constant('__NR_socket',97)
__NR_connect = Constant('__NR_connect',98)
__NR_accept = Constant('__NR_accept',99)
__NR_getpriority = Constant('__NR_getpriority',100)
__NR_rt_sigreturn = Constant('__NR_rt_sigreturn',101)
__NR_rt_sigaction = Constant('__NR_rt_sigaction',102)
__NR_rt_sigprocmask = Constant('__NR_rt_sigprocmask',103)
__NR_rt_sigpending = Constant('__NR_rt_sigpending',104)
__NR_rt_sigtimedwait = Constant('__NR_rt_sigtimedwait',105)
__NR_rt_sigqueueinfo = Constant('__NR_rt_sigqueueinfo',106)
__NR_rt_sigsuspend = Constant('__NR_rt_sigsuspend',107)
__NR_setresuid32 = Constant('__NR_setresuid32',108)
__NR_getresuid32 = Constant('__NR_getresuid32',109)
__NR_setresgid32 = Constant('__NR_setresgid32',110)
__NR_getresgid32 = Constant('__NR_getresgid32',111)
__NR_setregid32 = Constant('__NR_setregid32',112)
__NR_recvmsg = Constant('__NR_recvmsg',113)
__NR_sendmsg = Constant('__NR_sendmsg',114)
__NR_getgroups32 = Constant('__NR_getgroups32',115)
__NR_gettimeofday = Constant('__NR_gettimeofday',116)
__NR_getrusage = Constant('__NR_getrusage',117)
__NR_getsockopt = Constant('__NR_getsockopt',118)
__NR_getcwd = Constant('__NR_getcwd',119)
__NR_readv = Constant('__NR_readv',120)
__NR_writev = Constant('__NR_writev',121)
__NR_settimeofday = Constant('__NR_settimeofday',122)
__NR_fchown = Constant('__NR_fchown',123)
__NR_fchmod = Constant('__NR_fchmod',124)
__NR_recvfrom = Constant('__NR_recvfrom',125)
__NR_setreuid = Constant('__NR_setreuid',126)
__NR_setregid = Constant('__NR_setregid',127)
__NR_rename = Constant('__NR_rename',128)
__NR_truncate = Constant('__NR_truncate',129)
__NR_ftruncate = Constant('__NR_ftruncate',130)
__NR_flock = Constant('__NR_flock',131)
__NR_lstat64 = Constant('__NR_lstat64',132)
__NR_sendto = Constant('__NR_sendto',133)
__NR_shutdown = Constant('__NR_shutdown',134)
__NR_socketpair = Constant('__NR_socketpair',135)
__NR_mkdir = Constant('__NR_mkdir',136)
__NR_rmdir = Constant('__NR_rmdir',137)
__NR_utimes = Constant('__NR_utimes',138)
__NR_stat64 = Constant('__NR_stat64',139)
__NR_sendfile64 = Constant('__NR_sendfile64',140)
__NR_getpeername = Constant('__NR_getpeername',141)
__NR_futex = Constant('__NR_futex',142)
__NR_gettid = Constant('__NR_gettid',143)
__NR_getrlimit = Constant('__NR_getrlimit',144)
__NR_setrlimit = Constant('__NR_setrlimit',145)
__NR_pivot_root = Constant('__NR_pivot_root',146)
__NR_prctl = Constant('__NR_prctl',147)
__NR_pciconfig_read = Constant('__NR_pciconfig_read',148)
__NR_pciconfig_write = Constant('__NR_pciconfig_write',149)
__NR_getsockname = Constant('__NR_getsockname',150)
__NR_poll = Constant('__NR_poll',153)
__NR_getdents64 = Constant('__NR_getdents64',154)
__NR_fcntl64 = Constant('__NR_fcntl64',155)
__NR_statfs = Constant('__NR_statfs',157)
__NR_fstatfs = Constant('__NR_fstatfs',158)
__NR_umount = Constant('__NR_umount',159)
__NR_sched_set_affinity = Constant('__NR_sched_set_affinity',160)
__NR_sched_get_affinity = Constant('__NR_sched_get_affinity',161)
__NR_getdomainname = Constant('__NR_getdomainname',162)
__NR_setdomainname = Constant('__NR_setdomainname',163)
__NR_quotactl = Constant('__NR_quotactl',165)
__NR_set_tid_address = Constant('__NR_set_tid_address',166)
__NR_mount = Constant('__NR_mount',167)
__NR_ustat = Constant('__NR_ustat',168)
__NR_setxattr = Constant('__NR_setxattr',169)
__NR_lsetxattr = Constant('__NR_lsetxattr',170)
__NR_fsetxattr = Constant('__NR_fsetxattr',171)
__NR_getxattr = Constant('__NR_getxattr',172)
__NR_lgetxattr = Constant('__NR_lgetxattr',173)
__NR_getdents = Constant('__NR_getdents',174)
__NR_setsid = Constant('__NR_setsid',175)
__NR_fchdir = Constant('__NR_fchdir',176)
__NR_fgetxattr = Constant('__NR_fgetxattr',177)
__NR_listxattr = Constant('__NR_listxattr',178)
__NR_llistxattr = Constant('__NR_llistxattr',179)
__NR_flistxattr = Constant('__NR_flistxattr',180)
__NR_removexattr = Constant('__NR_removexattr',181)
__NR_lremovexattr = Constant('__NR_lremovexattr',182)
__NR_sigpending = Constant('__NR_sigpending',183)
__NR_query_module = Constant('__NR_query_module',184)
__NR_setpgid = Constant('__NR_setpgid',185)
__NR_fremovexattr = Constant('__NR_fremovexattr',186)
__NR_tkill = Constant('__NR_tkill',187)
__NR_exit_group = Constant('__NR_exit_group',188)
__NR_uname = Constant('__NR_uname',189)
__NR_init_module = Constant('__NR_init_module',190)
__NR_personality = Constant('__NR_personality',191)
__NR_remap_file_pages = Constant('__NR_remap_file_pages',192)
__NR_epoll_create = Constant('__NR_epoll_create',193)
__NR_epoll_ctl = Constant('__NR_epoll_ctl',194)
__NR_epoll_wait = Constant('__NR_epoll_wait',195)
__NR_getppid = Constant('__NR_getppid',197)
__NR_sigaction = Constant('__NR_sigaction',198)
__NR_sgetmask = Constant('__NR_sgetmask',199)
__NR_ssetmask = Constant('__NR_ssetmask',200)
__NR_sigsuspend = Constant('__NR_sigsuspend',201)
__NR_oldlstat = Constant('__NR_oldlstat',202)
__NR_uselib = Constant('__NR_uselib',203)
__NR_readdir = Constant('__NR_readdir',204)
__NR_readahead = Constant('__NR_readahead',205)
__NR_socketcall = Constant('__NR_socketcall',206)
__NR_syslog = Constant('__NR_syslog',207)
__NR_lookup_dcookie = Constant('__NR_lookup_dcookie',208)
__NR_fadvise64 = Constant('__NR_fadvise64',209)
__NR_fadvise64_64 = Constant('__NR_fadvise64_64',210)
__NR_tgkill = Constant('__NR_tgkill',211)
__NR_waitpid = Constant('__NR_waitpid',212)
__NR_swapoff = Constant('__NR_swapoff',213)
__NR_sysinfo = Constant('__NR_sysinfo',214)
__NR_ipc = Constant('__NR_ipc',215)
__NR_sigreturn = Constant('__NR_sigreturn',216)
__NR_clone = Constant('__NR_clone',217)
__NR_adjtimex = Constant('__NR_adjtimex',219)
__NR_sigprocmask = Constant('__NR_sigprocmask',220)
__NR_create_module = Constant('__NR_create_module',221)
__NR_delete_module = Constant('__NR_delete_module',222)
__NR_get_kernel_syms = Constant('__NR_get_kernel_syms',223)
__NR_getpgid = Constant('__NR_getpgid',224)
__NR_bdflush = Constant('__NR_bdflush',225)
__NR_sysfs = Constant('__NR_sysfs',226)
__NR_afs_syscall = Constant('__NR_afs_syscall',227)
__NR_setfsuid = Constant('__NR_setfsuid',228)
__NR_setfsgid = Constant('__NR_setfsgid',229)
__NR__newselect = Constant('__NR__newselect',230)
__NR_time = Constant('__NR_time',231)
__NR_stime = Constant('__NR_stime',233)
__NR_statfs64 = Constant('__NR_statfs64',234)
__NR_fstatfs64 = Constant('__NR_fstatfs64',235)
__NR__llseek = Constant('__NR__llseek',236)
__NR_mlock = Constant('__NR_mlock',237)
__NR_munlock = Constant('__NR_munlock',238)
__NR_mlockall = Constant('__NR_mlockall',239)
__NR_munlockall = Constant('__NR_munlockall',240)
__NR_sched_setparam = Constant('__NR_sched_setparam',241)
__NR_sched_getparam = Constant('__NR_sched_getparam',242)
__NR_sched_setscheduler = Constant('__NR_sched_setscheduler',243)
__NR_sched_getscheduler = Constant('__NR_sched_getscheduler',244)
__NR_sched_yield = Constant('__NR_sched_yield',245)
__NR_sched_get_priority_max = Constant('__NR_sched_get_priority_max',246)
__NR_sched_get_priority_min = Constant('__NR_sched_get_priority_min',247)
__NR_sched_rr_get_interval = Constant('__NR_sched_rr_get_interval',248)
__NR_nanosleep = Constant('__NR_nanosleep',249)
__NR_mremap = Constant('__NR_mremap',250)
__NR__sysctl = Constant('__NR__sysctl',251)
__NR_getsid = Constant('__NR_getsid',252)
__NR_fdatasync = Constant('__NR_fdatasync',253)
__NR_nfsservctl = Constant('__NR_nfsservctl',254)
__NR_aplib = Constant('__NR_aplib',255)
__NR_clock_settime = Constant('__NR_clock_settime',256)
__NR_clock_gettime = Constant('__NR_clock_gettime',257)
__NR_clock_getres = Constant('__NR_clock_getres',258)
__NR_clock_nanosleep = Constant('__NR_clock_nanosleep',259)
__NR_sched_getaffinity = Constant('__NR_sched_getaffinity',260)
__NR_sched_setaffinity = Constant('__NR_sched_setaffinity',261)
__NR_timer_settime = Constant('__NR_timer_settime',262)
__NR_timer_gettime = Constant('__NR_timer_gettime',263)
__NR_timer_getoverrun = Constant('__NR_timer_getoverrun',264)
__NR_timer_delete = Constant('__NR_timer_delete',265)
__NR_timer_create = Constant('__NR_timer_create',266)
__NR_io_setup = Constant('__NR_io_setup',268)
__NR_io_destroy = Constant('__NR_io_destroy',269)
__NR_io_submit = Constant('__NR_io_submit',270)
__NR_io_cancel = Constant('__NR_io_cancel',271)
__NR_io_getevents = Constant('__NR_io_getevents',272)
__NR_mq_open = Constant('__NR_mq_open',273)
__NR_mq_unlink = Constant('__NR_mq_unlink',274)
__NR_mq_timedsend = Constant('__NR_mq_timedsend',275)
__NR_mq_timedreceive = Constant('__NR_mq_timedreceive',276)
__NR_mq_notify = Constant('__NR_mq_notify',277)
__NR_mq_getsetattr = Constant('__NR_mq_getsetattr',278)
__NR_waitid = Constant('__NR_waitid',279)
__NR_sys_setaltroot = Constant('__NR_sys_setaltroot',280)
__NR_add_key = Constant('__NR_add_key',281)
__NR_request_key = Constant('__NR_request_key',282)
__NR_keyctl = Constant('__NR_keyctl',283)
__NR_openat = Constant('__NR_openat',284)
__NR_mkdirat = Constant('__NR_mkdirat',285)
__NR_mknodat = Constant('__NR_mknodat',286)
__NR_fchownat = Constant('__NR_fchownat',287)
__NR_futimesat = Constant('__NR_futimesat',288)
__NR_fstatat64 = Constant('__NR_fstatat64',289)
__NR_unlinkat = Constant('__NR_unlinkat',290)
__NR_renameat = Constant('__NR_renameat',291)
__NR_linkat = Constant('__NR_linkat',292)
__NR_symlinkat = Constant('__NR_symlinkat',293)
__NR_readlinkat = Constant('__NR_readlinkat',294)
__NR_fchmodat = Constant('__NR_fchmodat',295)
__NR_faccessat = Constant('__NR_faccessat',296)
__NR_pselect6 = Constant('__NR_pselect6',297)
__NR_ppoll = Constant('__NR_ppoll',298)
__NR_unshare = Constant('__NR_unshare',299)
__NR_set_robust_list = Constant('__NR_set_robust_list',300)
__NR_get_robust_list = Constant('__NR_get_robust_list',301)
__NR_migrate_pages = Constant('__NR_migrate_pages',302)
__NR_mbind = Constant('__NR_mbind',303)
__NR_get_mempolicy = Constant('__NR_get_mempolicy',304)
__NR_set_mempolicy = Constant('__NR_set_mempolicy',305)
__NR_kexec_load = Constant('__NR_kexec_load',306)
__NR_move_pages = Constant('__NR_move_pages',307)
__NR_getcpu = Constant('__NR_getcpu',308)
__NR_epoll_pwait = Constant('__NR_epoll_pwait',309)
__NR_utimensat = Constant('__NR_utimensat',310)
__NR_signalfd = Constant('__NR_signalfd',311)
__NR_timerfd = Constant('__NR_timerfd',312)
__NR_eventfd = Constant('__NR_eventfd',313)
__NR_fallocate = Constant('__NR_fallocate',314)
__NR_timerfd_settime = Constant('__NR_timerfd_settime',315)
__NR_timerfd_gettime = Constant('__NR_timerfd_gettime',316)
MAP_32BIT = Constant('MAP_32BIT',0x40)
INADDR_ANY = Constant('INADDR_ANY',0)
INADDR_BROADCAST = Constant('INADDR_BROADCAST',0xffffffff)
INADDR_NONE = Constant('INADDR_NONE',0xffffffff)
INADDR_LOOPBACK = Constant('INADDR_LOOPBACK',0x7f000001)
EPERM = Constant('EPERM',1)
ENOENT = Constant('ENOENT',2)
ESRCH = Constant('ESRCH',3)
EINTR = Constant('EINTR',4)
EIO = Constant('EIO',5)
ENXIO = Constant('ENXIO',6)
E2BIG = Constant('E2BIG',7)
ENOEXEC = Constant('ENOEXEC',8)
EBADF = Constant('EBADF',9)
ECHILD = Constant('ECHILD',10)
EAGAIN = Constant('EAGAIN',11)
ENOMEM = Constant('ENOMEM',12)
EACCES = Constant('EACCES',13)
EFAULT = Constant('EFAULT',14)
ENOTBLK = Constant('ENOTBLK',15)
EBUSY = Constant('EBUSY',16)
EEXIST = Constant('EEXIST',17)
EXDEV = Constant('EXDEV',18)
ENODEV = Constant('ENODEV',19)
ENOTDIR = Constant('ENOTDIR',20)
EISDIR = Constant('EISDIR',21)
EINVAL = Constant('EINVAL',22)
ENFILE = Constant('ENFILE',23)
EMFILE = Constant('EMFILE',24)
ENOTTY = Constant('ENOTTY',25)
ETXTBSY = Constant('ETXTBSY',26)
EFBIG = Constant('EFBIG',27)
ENOSPC = Constant('ENOSPC',28)
ESPIPE = Constant('ESPIPE',29)
EROFS = Constant('EROFS',30)
EMLINK = Constant('EMLINK',31)
EPIPE = Constant('EPIPE',32)
EDOM = Constant('EDOM',33)
ERANGE = Constant('ERANGE',34)
EWOULDBLOCK = Constant('EWOULDBLOCK',11)
EINPROGRESS = Constant('EINPROGRESS',36)
EALREADY = Constant('EALREADY',37)
ENOTSOCK = Constant('ENOTSOCK',38)
EDESTADDRREQ = Constant('EDESTADDRREQ',39)
EMSGSIZE = Constant('EMSGSIZE',40)
EPROTOTYPE = Constant('EPROTOTYPE',41)
ENOPROTOOPT = Constant('ENOPROTOOPT',42)
EPROTONOSUPPORT = Constant('EPROTONOSUPPORT',43)
ESOCKTNOSUPPORT = Constant('ESOCKTNOSUPPORT',44)
EOPNOTSUPP = Constant('EOPNOTSUPP',45)
ENOTSUP = Constant('ENOTSUP',45)
EPFNOSUPPORT = Constant('EPFNOSUPPORT',46)
EAFNOSUPPORT = Constant('EAFNOSUPPORT',47)
EADDRINUSE = Constant('EADDRINUSE',48)
EADDRNOTAVAIL = Constant('EADDRNOTAVAIL',49)
ENETDOWN = Constant('ENETDOWN',50)
ENETUNREACH = Constant('ENETUNREACH',51)
ENETRESET = Constant('ENETRESET',52)
ECONNABORTED = Constant('ECONNABORTED',53)
ECONNRESET = Constant('ECONNRESET',54)
ENOBUFS = Constant('ENOBUFS',55)
EISCONN = Constant('EISCONN',56)
ENOTCONN = Constant('ENOTCONN',57)
ESHUTDOWN = Constant('ESHUTDOWN',58)
ETOOMANYREFS = Constant('ETOOMANYREFS',59)
ETIMEDOUT = Constant('ETIMEDOUT',60)
ECONNREFUSED = Constant('ECONNREFUSED',61)
ELOOP = Constant('ELOOP',62)
ENAMETOOLONG = Constant('ENAMETOOLONG',63)
EHOSTDOWN = Constant('EHOSTDOWN',64)
EHOSTUNREACH = Constant('EHOSTUNREACH',65)
ENOTEMPTY = Constant('ENOTEMPTY',66)
EPROCLIM = Constant('EPROCLIM',67)
EUSERS = Constant('EUSERS',68)
EDQUOT = Constant('EDQUOT',69)
ESTALE = Constant('ESTALE',70)
EREMOTE = Constant('EREMOTE',71)
ENOSTR = Constant('ENOSTR',72)
ETIME = Constant('ETIME',73)
ENOSR = Constant('ENOSR',74)
ENOMSG = Constant('ENOMSG',75)
EBADMSG = Constant('EBADMSG',76)
EIDRM = Constant('EIDRM',77)
EDEADLK = Constant('EDEADLK',78)
ENOLCK = Constant('ENOLCK',79)
ENONET = Constant('ENONET',80)
ERREMOTE = Constant('ERREMOTE',81)
ENOLINK = Constant('ENOLINK',82)
EADV = Constant('EADV',83)
ESRMNT = Constant('ESRMNT',84)
ECOMM = Constant('ECOMM',85)
EPROTO = Constant('EPROTO',86)
EMULTIHOP = Constant('EMULTIHOP',87)
EDOTDOT = Constant('EDOTDOT',88)
EREMCHG = Constant('EREMCHG',89)
ENOSYS = Constant('ENOSYS',90)
ESTRPIPE = Constant('ESTRPIPE',91)
EOVERFLOW = Constant('EOVERFLOW',92)
EBADFD = Constant('EBADFD',93)
ECHRNG = Constant('ECHRNG',94)
EL2NSYNC = Constant('EL2NSYNC',95)
EL3HLT = Constant('EL3HLT',96)
EL3RST = Constant('EL3RST',97)
ELNRNG = Constant('ELNRNG',98)
EUNATCH = Constant('EUNATCH',99)
ENOCSI = Constant('ENOCSI',100)
EL2HLT = Constant('EL2HLT',101)
EBADE = Constant('EBADE',102)
EBADR = Constant('EBADR',103)
EXFULL = Constant('EXFULL',104)
ENOANO = Constant('ENOANO',105)
EBADRQC = Constant('EBADRQC',106)
EBADSLT = Constant('EBADSLT',107)
EDEADLOCK = Constant('EDEADLOCK',108)
EBFONT = Constant('EBFONT',109)
ELIBEXEC = Constant('ELIBEXEC',110)
ENODATA = Constant('ENODATA',111)
ELIBBAD = Constant('ELIBBAD',112)
ENOPKG = Constant('ENOPKG',113)
ELIBACC = Constant('ELIBACC',114)
ENOTUNIQ = Constant('ENOTUNIQ',115)
ERESTART = Constant('ERESTART',116)
EUCLEAN = Constant('EUCLEAN',117)
ENOTNAM = Constant('ENOTNAM',118)
ENAVAIL = Constant('ENAVAIL',119)
EISNAM = Constant('EISNAM',120)
EREMOTEIO = Constant('EREMOTEIO',121)
EILSEQ = Constant('EILSEQ',122)
ELIBMAX = Constant('ELIBMAX',123)
ELIBSCN = Constant('ELIBSCN',124)
ENOMEDIUM = Constant('ENOMEDIUM',125)
EMEDIUMTYPE = Constant('EMEDIUMTYPE',126)
ECANCELED = Constant('ECANCELED',127)
ENOKEY = Constant('ENOKEY',128)
EKEYEXPIRED = Constant('EKEYEXPIRED',129)
EKEYREVOKED = Constant('EKEYREVOKED',130)
EKEYREJECTED = Constant('EKEYREJECTED',131)
__SYS_NERR = Constant('__SYS_NERR',((131) + 1))
__LITTLE_ENDIAN = Constant('__LITTLE_ENDIAN',1234)
__BIG_ENDIAN = Constant('__BIG_ENDIAN',4321)
__BYTE_ORDER = Constant('__BYTE_ORDER',4321)
__FLOAT_WORD_ORDER = Constant('__FLOAT_WORD_ORDER',4321)
LITTLE_ENDIAN = Constant('LITTLE_ENDIAN',1234)
BIG_ENDIAN = Constant('BIG_ENDIAN',4321)
BYTE_ORDER = Constant('BYTE_ORDER',4321)
__WORDSIZE = Constant('__WORDSIZE',32)
__FSUID_H = Constant('__FSUID_H',1)
NSIG = Constant('NSIG',32)
_NSIG = Constant('_NSIG',64)
SIGHUP = Constant('SIGHUP',1)
SIGINT = Constant('SIGINT',2)
SIGQUIT = Constant('SIGQUIT',3)
SIGILL = Constant('SIGILL',4)
SIGTRAP = Constant('SIGTRAP',5)
SIGABRT = Constant('SIGABRT',6)
SIGIOT = Constant('SIGIOT',6)
SIGFPE = Constant('SIGFPE',8)
SIGKILL = Constant('SIGKILL',9)
SIGSEGV = Constant('SIGSEGV',11)
SIGPIPE = Constant('SIGPIPE',13)
SIGALRM = Constant('SIGALRM',14)
SIGTERM = Constant('SIGTERM',15)
SIGUNUSED = Constant('SIGUNUSED',31)
SIGEMT = Constant('SIGEMT',7)
SIGBUS = Constant('SIGBUS',10)
SIGSYS = Constant('SIGSYS',12)
SIGURG = Constant('SIGURG',16)
SIGSTOP = Constant('SIGSTOP',17)
SIGTSTP = Constant('SIGTSTP',18)
SIGCONT = Constant('SIGCONT',19)
SIGCHLD = Constant('SIGCHLD',20)
SIGTTIN = Constant('SIGTTIN',21)
SIGTTOU = Constant('SIGTTOU',22)
SIGIO = Constant('SIGIO',23)
SIGXCPU = Constant('SIGXCPU',24)
SIGXFSZ = Constant('SIGXFSZ',25)
SIGVTALRM = Constant('SIGVTALRM',26)
SIGPROF = Constant('SIGPROF',27)
SIGWINCH = Constant('SIGWINCH',28)
SIGPWR = Constant('SIGPWR',29)
SIGUSR1 = Constant('SIGUSR1',30)
SIGUSR2 = Constant('SIGUSR2',31)
SIGCLD = Constant('SIGCLD',20)
SIGPOLL = Constant('SIGPOLL',23)
SIGLOST = Constant('SIGLOST',29)
SIGRTMIN = Constant('SIGRTMIN',32)
SIGRTMAX = Constant('SIGRTMAX',(64-1))
SV_SSTACK = Constant('SV_SSTACK',1)
SV_INTR = Constant('SV_INTR',2)
SV_RESET = Constant('SV_RESET',4)
SV_IGNCHILD = Constant('SV_IGNCHILD',8)
SA_NOCLDSTOP = Constant('SA_NOCLDSTOP',8)
SA_STACK = Constant('SA_STACK',1)
SA_ONSTACK = Constant('SA_ONSTACK',1)
SA_RESTART = Constant('SA_RESTART',2)
SA_RESETHAND = Constant('SA_RESETHAND',4)
SA_INTERRUPT = Constant('SA_INTERRUPT',0x10)
SA_NODEFER = Constant('SA_NODEFER',0x20)
SA_SHIRQ = Constant('SA_SHIRQ',0x40)
SA_NOCLDWAIT = Constant('SA_NOCLDWAIT',0x100)
SA_SIGINFO = Constant('SA_SIGINFO',0x200)
SA_NOMASK = Constant('SA_NOMASK',0x20)
SA_ONESHOT = Constant('SA_ONESHOT',4)
SS_ONSTACK = Constant('SS_ONSTACK',1)
SS_DISABLE = Constant('SS_DISABLE',2)
MINSIGSTKSZ = Constant('MINSIGSTKSZ',2048)
SIGSTKSZ = Constant('SIGSTKSZ',8192)
SIG_BLOCK = Constant('SIG_BLOCK',1)
SIG_UNBLOCK = Constant('SIG_UNBLOCK',2)
SIG_SETMASK = Constant('SIG_SETMASK',4)
SI_MAX_SIZE = Constant('SI_MAX_SIZE',128)
SIGEV_SIGNAL = Constant('SIGEV_SIGNAL',0)
SIGEV_NONE = Constant('SIGEV_NONE',1)
SIGEV_THREAD = Constant('SIGEV_THREAD',2)
SIGEV_THREAD_ID = Constant('SIGEV_THREAD_ID',4)
SIGEV_MAX_SIZE = Constant('SIGEV_MAX_SIZE',64)
_SYS_TIME_H = Constant('_SYS_TIME_H',1)
ITIMER_REAL = Constant('ITIMER_REAL',0)
ITIMER_VIRTUAL = Constant('ITIMER_VIRTUAL',1)
ITIMER_PROF = Constant('ITIMER_PROF',2)
__SUNOS_MAXWIN = Constant('__SUNOS_MAXWIN',31)
MC_TSTATE = Constant('MC_TSTATE',0)
MC_PC = Constant('MC_PC',1)
MC_NPC = Constant('MC_NPC',2)
MC_Y = Constant('MC_Y',3)
MC_G1 = Constant('MC_G1',4)
MC_G2 = Constant('MC_G2',5)
MC_G3 = Constant('MC_G3',6)
MC_G4 = Constant('MC_G4',7)
MC_G5 = Constant('MC_G5',8)
MC_G6 = Constant('MC_G6',9)
MC_G7 = Constant('MC_G7',10)
MC_O0 = Constant('MC_O0',11)
MC_O1 = Constant('MC_O1',12)
MC_O2 = Constant('MC_O2',13)
MC_O3 = Constant('MC_O3',14)
MC_O4 = Constant('MC_O4',15)
MC_O5 = Constant('MC_O5',16)
MC_O6 = Constant('MC_O6',17)
MC_O7 = Constant('MC_O7',18)
MC_NGREG = Constant('MC_NGREG',19)
MC_MAXFPQ = Constant('MC_MAXFPQ',16)
FD_SETSIZE = Constant('FD_SETSIZE',1024)
R_OK = Constant('R_OK',4)
W_OK = Constant('W_OK',2)
X_OK = Constant('X_OK',1)
F_OK = Constant('F_OK',0)
SEEK_SET = Constant('SEEK_SET',0)
SEEK_CUR = Constant('SEEK_CUR',1)
SEEK_END = Constant('SEEK_END',2)
STDIN_FILENO = Constant('STDIN_FILENO',0)
STDOUT_FILENO = Constant('STDOUT_FILENO',1)
STDERR_FILENO = Constant('STDERR_FILENO',2)
_CS_PATH = Constant('_CS_PATH',1)
_SC_CLK_TCK = Constant('_SC_CLK_TCK',1)
_SC_ARG_MAX = Constant('_SC_ARG_MAX',2)
_SC_NGROUPS_MAX = Constant('_SC_NGROUPS_MAX',3)
_SC_OPEN_MAX = Constant('_SC_OPEN_MAX',4)
_SC_PAGESIZE = Constant('_SC_PAGESIZE',5)
_SC_NPROCESSORS_ONLN = Constant('_SC_NPROCESSORS_ONLN',6)
_SC_NPROCESSORS_CONF = Constant('_SC_NPROCESSORS_CONF',6)
_SC_PHYS_PAGES = Constant('_SC_PHYS_PAGES',7)
_PC_PATH_MAX = Constant('_PC_PATH_MAX',1)
_PC_VDISABLE = Constant('_PC_VDISABLE',2)
L_cuserid = Constant('L_cuserid',17)
_POSIX_VERSION = Constant('_POSIX_VERSION',199506)
F_ULOCK = Constant('F_ULOCK',0)
F_LOCK = Constant('F_LOCK',1)
F_TLOCK = Constant('F_TLOCK',2)
F_TEST = Constant('F_TEST',3)
S_IFMT = Constant('S_IFMT',0o0170000)
S_IFSOCK = Constant('S_IFSOCK',0o140000)
S_IFLNK = Constant('S_IFLNK',0o120000)
S_IFREG = Constant('S_IFREG',0o100000)
S_IFBLK = Constant('S_IFBLK',0o060000)
S_IFDIR = Constant('S_IFDIR',0o040000)
S_IFCHR = Constant('S_IFCHR',0o020000)
S_IFIFO = Constant('S_IFIFO',0o010000)
S_ISUID = Constant('S_ISUID',0o004000)
S_ISGID = Constant('S_ISGID',0o002000)
S_ISVTX = Constant('S_ISVTX',0o001000)
S_IRWXU = Constant('S_IRWXU',0o0700)
S_IRUSR = Constant('S_IRUSR',0o0400)
S_IWUSR = Constant('S_IWUSR',0o0200)
S_IXUSR = Constant('S_IXUSR',0o0100)
S_IRWXG = Constant('S_IRWXG',0o0070)
S_IRGRP = Constant('S_IRGRP',0o0040)
S_IWGRP = Constant('S_IWGRP',0o0020)
S_IXGRP = Constant('S_IXGRP',0o0010)
S_IRWXO = Constant('S_IRWXO',0o0007)
S_IROTH = Constant('S_IROTH',0o0004)
S_IWOTH = Constant('S_IWOTH',0o0002)
S_IXOTH = Constant('S_IXOTH',0o0001)
S_IREAD = Constant('S_IREAD',0o0400)
S_IWRITE = Constant('S_IWRITE',0o0200)
S_IEXEC = Constant('S_IEXEC',0o0100)
F_LINUX_SPECIFIC_BASE = Constant('F_LINUX_SPECIFIC_BASE',1024)
O_RDONLY = Constant('O_RDONLY',0x0000)
O_WRONLY = Constant('O_WRONLY',0x0001)
O_RDWR = Constant('O_RDWR',0x0002)
O_ACCMODE = Constant('O_ACCMODE',0x0003)
O_APPEND = Constant('O_APPEND',0x0008)
FASYNC = Constant('FASYNC',0x0040)
O_CREAT = Constant('O_CREAT',0x0200)
O_TRUNC = Constant('O_TRUNC',0x0400)
O_EXCL = Constant('O_EXCL',0x0800)
O_SYNC = Constant('O_SYNC',0x2000)
O_NONBLOCK = Constant('O_NONBLOCK',0x4000)
O_NDELAY = Constant('O_NDELAY',(0x0004 | 0x4000))
O_NOCTTY = Constant('O_NOCTTY',0x8000)
O_DIRECTORY = Constant('O_DIRECTORY',0x10000)
O_NOFOLLOW = Constant('O_NOFOLLOW',0x20000)
O_LARGEFILE = Constant('O_LARGEFILE',0x40000)
O_DIRECT = Constant('O_DIRECT',0x100000)
O_NOATIME = Constant('O_NOATIME',0x200000)
F_DUPFD = Constant('F_DUPFD',0)
F_GETFD = Constant('F_GETFD',1)
F_SETFD = Constant('F_SETFD',2)
F_GETFL = Constant('F_GETFL',3)
F_SETFL = Constant('F_SETFL',4)
F_GETOWN = Constant('F_GETOWN',5)
F_SETOWN = Constant('F_SETOWN',6)
F_GETLK = Constant('F_GETLK',7)
F_SETLK = Constant('F_SETLK',8)
F_SETLKW = Constant('F_SETLKW',9)
F_SETSIG = Constant('F_SETSIG',10)
F_GETSIG = Constant('F_GETSIG',11)
F_GETLK64 = Constant('F_GETLK64',12)
F_SETLK64 = Constant('F_SETLK64',13)
F_SETLKW64 = Constant('F_SETLKW64',14)
FD_CLOEXEC = Constant('FD_CLOEXEC',1)
F_RDLCK = Constant('F_RDLCK',1)
F_WRLCK = Constant('F_WRLCK',2)
F_UNLCK = Constant('F_UNLCK',3)
F_EXLCK = Constant('F_EXLCK',4)
F_SHLCK = Constant('F_SHLCK',8)
F_INPROGRESS = Constant('F_INPROGRESS',16)
LOCK_SH = Constant('LOCK_SH',1)
LOCK_EX = Constant('LOCK_EX',2)
LOCK_NB = Constant('LOCK_NB',4)
LOCK_UN = Constant('LOCK_UN',8)
LOCK_MAND = Constant('LOCK_MAND',32)
LOCK_READ = Constant('LOCK_READ',64)
LOCK_WRITE = Constant('LOCK_WRITE',128)
LOCK_RW = Constant('LOCK_RW',192)
O_ASYNC = Constant('O_ASYNC',0x0040)
MREMAP_MAYMOVE = Constant('MREMAP_MAYMOVE',1)
MREMAP_FIXED = Constant('MREMAP_FIXED',2)
PROT_READ = Constant('PROT_READ',0x1)
PROT_WRITE = Constant('PROT_WRITE',0x2)
PROT_EXEC = Constant('PROT_EXEC',0x4)
PROT_NONE = Constant('PROT_NONE',0x0)
MAP_SHARED = Constant('MAP_SHARED',0x01)
MAP_PRIVATE = Constant('MAP_PRIVATE',0x02)
MAP_FIXED = Constant('MAP_FIXED',0x10)
MAP_ANONYMOUS = Constant('MAP_ANONYMOUS',0x20)
MAP_RENAME = Constant('MAP_RENAME',0x20)
MAP_NORESERVE = Constant('MAP_NORESERVE',0x40)
MAP_INHERIT = Constant('MAP_INHERIT',0x80)
MAP_LOCKED = Constant('MAP_LOCKED',0x100)
_MAP_NEW = Constant('_MAP_NEW',0x80000000)
MAP_GROWSDOWN = Constant('MAP_GROWSDOWN',0x0100)
MAP_DENYWRITE = Constant('MAP_DENYWRITE',0x0800)
MAP_EXECUTABLE = Constant('MAP_EXECUTABLE',0x1000)
MAP_POPULATE = Constant('MAP_POPULATE',0x8000)
MS_ASYNC = Constant('MS_ASYNC',1)
MS_INVALIDATE = Constant('MS_INVALIDATE',2)
MS_SYNC = Constant('MS_SYNC',4)
MCL_CURRENT = Constant('MCL_CURRENT',0x2000)
MCL_FUTURE = Constant('MCL_FUTURE',0x4000)
MADV_NORMAL = Constant('MADV_NORMAL',0x0)
MADV_RANDOM = Constant('MADV_RANDOM',0x1)
MADV_SEQUENTIAL = Constant('MADV_SEQUENTIAL',0x2)
MADV_WILLNEED = Constant('MADV_WILLNEED',0x3)
MADV_DONTNEED = Constant('MADV_DONTNEED',0x4)
MADV_FREE = Constant('MADV_FREE',0x5)
MAP_ANON = Constant('MAP_ANON',0x20)
MAP_FILE = Constant('MAP_FILE',0)
SOL_SOCKET = Constant('SOL_SOCKET',0xffff)
SO_DEBUG = Constant('SO_DEBUG',0x0001)
SO_PASSCRED = Constant('SO_PASSCRED',0x0002)
SO_REUSEADDR = Constant('SO_REUSEADDR',0x0004)
SO_KEEPALIVE = Constant('SO_KEEPALIVE',0x0008)
SO_DONTROUTE = Constant('SO_DONTROUTE',0x0010)
SO_BROADCAST = Constant('SO_BROADCAST',0x0020)
SO_PEERCRED = Constant('SO_PEERCRED',0x0040)
SO_LINGER = Constant('SO_LINGER',0x0080)
SO_OOBINLINE = Constant('SO_OOBINLINE',0x0100)
SO_BSDCOMPAT = Constant('SO_BSDCOMPAT',0x0400)
SO_RCVLOWAT = Constant('SO_RCVLOWAT',0x0800)
SO_SNDLOWAT = Constant('SO_SNDLOWAT',0x1000)
SO_RCVTIMEO = Constant('SO_RCVTIMEO',0x2000)
SO_SNDTIMEO = Constant('SO_SNDTIMEO',0x4000)
SO_ACCEPTCONN = Constant('SO_ACCEPTCONN',0x8000)
SO_DONTLINGER = Constant('SO_DONTLINGER',(~0x0080))
SO_SNDBUF = Constant('SO_SNDBUF',0x1001)
SO_RCVBUF = Constant('SO_RCVBUF',0x1002)
SO_SNDBUFFORCE = Constant('SO_SNDBUFFORCE',0x100a)
SO_RCVBUFFORCE = Constant('SO_RCVBUFFORCE',0x100b)
SO_ERROR = Constant('SO_ERROR',0x1007)
SO_TYPE = Constant('SO_TYPE',0x1008)
SO_ATTACH_FILTER = Constant('SO_ATTACH_FILTER',0x001a)
SO_DETACH_FILTER = Constant('SO_DETACH_FILTER',0x001b)
SO_PEERNAME = Constant('SO_PEERNAME',0x001c)
SO_TIMESTAMP = Constant('SO_TIMESTAMP',0x001d)
SCM_TIMESTAMP = Constant('SCM_TIMESTAMP',0x001d)
SO_SECURITY_AUTHENTICATION = Constant('SO_SECURITY_AUTHENTICATION',0x5001)
SO_SECURITY_ENCRYPTION_TRANSPORT = Constant('SO_SECURITY_ENCRYPTION_TRANSPORT',0x5002)
SO_SECURITY_ENCRYPTION_NETWORK = Constant('SO_SECURITY_ENCRYPTION_NETWORK',0x5004)
SOCK_STREAM = Constant('SOCK_STREAM',1)
SOCK_DGRAM = Constant('SOCK_DGRAM',2)
SOCK_RAW = Constant('SOCK_RAW',3)
SOCK_RDM = Constant('SOCK_RDM',4)
SOCK_SEQPACKET = Constant('SOCK_SEQPACKET',5)
SOCK_PACKET = Constant('SOCK_PACKET',10)
UIO_FASTIOV = Constant('UIO_FASTIOV',8)
UIO_MAXIOV = Constant('UIO_MAXIOV',1024)
SCM_RIGHTS = Constant('SCM_RIGHTS',0x01)
SCM_CREDENTIALS = Constant('SCM_CREDENTIALS',0x02)
SCM_CONNECT = Constant('SCM_CONNECT',0x03)
AF_UNSPEC = Constant('AF_UNSPEC',0)
AF_UNIX = Constant('AF_UNIX',1)
AF_LOCAL = Constant('AF_LOCAL',1)
AF_INET = Constant('AF_INET',2)
AF_AX25 = Constant('AF_AX25',3)
AF_IPX = Constant('AF_IPX',4)
AF_APPLETALK = Constant('AF_APPLETALK',5)
AF_NETROM = Constant('AF_NETROM',6)
AF_BRIDGE = Constant('AF_BRIDGE',7)
AF_ATMPVC = Constant('AF_ATMPVC',8)
AF_X25 = Constant('AF_X25',9)
AF_INET6 = Constant('AF_INET6',10)
AF_ROSE = Constant('AF_ROSE',11)
AF_DECnet = Constant('AF_DECnet',12)
AF_NETBEUI = Constant('AF_NETBEUI',13)
AF_SECURITY = Constant('AF_SECURITY',14)
AF_KEY = Constant('AF_KEY',15)
AF_NETLINK = Constant('AF_NETLINK',16)
AF_ROUTE = Constant('AF_ROUTE',16)
AF_PACKET = Constant('AF_PACKET',17)
AF_ASH = Constant('AF_ASH',18)
AF_ECONET = Constant('AF_ECONET',19)
AF_ATMSVC = Constant('AF_ATMSVC',20)
AF_SNA = Constant('AF_SNA',22)
AF_IRDA = Constant('AF_IRDA',23)
AF_PPPOX = Constant('AF_PPPOX',24)
AF_WANPIPE = Constant('AF_WANPIPE',25)
AF_MAX = Constant('AF_MAX',32)
PF_UNSPEC = Constant('PF_UNSPEC',0)
PF_UNIX = Constant('PF_UNIX',1)
PF_LOCAL = Constant('PF_LOCAL',1)
PF_INET = Constant('PF_INET',2)
PF_AX25 = Constant('PF_AX25',3)
PF_IPX = Constant('PF_IPX',4)
PF_APPLETALK = Constant('PF_APPLETALK',5)
PF_NETROM = Constant('PF_NETROM',6)
PF_BRIDGE = Constant('PF_BRIDGE',7)
PF_ATMPVC = Constant('PF_ATMPVC',8)
PF_X25 = Constant('PF_X25',9)
PF_INET6 = Constant('PF_INET6',10)
PF_ROSE = Constant('PF_ROSE',11)
PF_DECnet = Constant('PF_DECnet',12)
PF_NETBEUI = Constant('PF_NETBEUI',13)
PF_SECURITY = Constant('PF_SECURITY',14)
PF_KEY = Constant('PF_KEY',15)
PF_NETLINK = Constant('PF_NETLINK',16)
PF_ROUTE = Constant('PF_ROUTE',16)
PF_PACKET = Constant('PF_PACKET',17)
PF_ASH = Constant('PF_ASH',18)
PF_ECONET = Constant('PF_ECONET',19)
PF_ATMSVC = Constant('PF_ATMSVC',20)
PF_SNA = Constant('PF_SNA',22)
PF_IRDA = Constant('PF_IRDA',23)
PF_PPPOX = Constant('PF_PPPOX',24)
PF_WANPIPE = Constant('PF_WANPIPE',25)
PF_MAX = Constant('PF_MAX',32)
SOMAXCONN = Constant('SOMAXCONN',128)
MSG_OOB = Constant('MSG_OOB',1)
MSG_PEEK = Constant('MSG_PEEK',2)
MSG_DONTROUTE = Constant('MSG_DONTROUTE',4)
MSG_TRYHARD = Constant('MSG_TRYHARD',4)
MSG_CTRUNC = Constant('MSG_CTRUNC',8)
MSG_PROBE = Constant('MSG_PROBE',0x10)
MSG_TRUNC = Constant('MSG_TRUNC',0x20)
MSG_DONTWAIT = Constant('MSG_DONTWAIT',0x40)
MSG_EOR = Constant('MSG_EOR',0x80)
MSG_WAITALL = Constant('MSG_WAITALL',0x100)
MSG_FIN = Constant('MSG_FIN',0x200)
MSG_EOF = Constant('MSG_EOF',0x200)
MSG_SYN = Constant('MSG_SYN',0x400)
MSG_CONFIRM = Constant('MSG_CONFIRM',0x800)
MSG_RST = Constant('MSG_RST',0x1000)
MSG_ERRQUEUE = Constant('MSG_ERRQUEUE',0x2000)
MSG_NOSIGNAL = Constant('MSG_NOSIGNAL',0x4000)
MSG_MORE = Constant('MSG_MORE',0x8000)
SOL_IP = Constant('SOL_IP',0)
SOL_TCP = Constant('SOL_TCP',6)
SOL_UDP = Constant('SOL_UDP',17)
SOL_IPV6 = Constant('SOL_IPV6',41)
SOL_ICMPV6 = Constant('SOL_ICMPV6',58)
SOL_RAW = Constant('SOL_RAW',255)
SOL_IPX = Constant('SOL_IPX',256)
SOL_AX25 = Constant('SOL_AX25',257)
SOL_ATALK = Constant('SOL_ATALK',258)
SOL_NETROM = Constant('SOL_NETROM',259)
SOL_ROSE = Constant('SOL_ROSE',260)
SOL_DECNET = Constant('SOL_DECNET',261)
SOL_X25 = Constant('SOL_X25',262)
SOL_PACKET = Constant('SOL_PACKET',263)
SOL_ATM = Constant('SOL_ATM',264)
SOL_AAL = Constant('SOL_AAL',265)
SOL_IRDA = Constant('SOL_IRDA',266)
IPX_TYPE = Constant('IPX_TYPE',1)
SHUT_RD = Constant('SHUT_RD',0)
SHUT_WR = Constant('SHUT_WR',1)
SHUT_RDWR = Constant('SHUT_RDWR',2)
NI_NOFQDN = Constant('NI_NOFQDN',1)
NI_NUMERICHOST = Constant('NI_NUMERICHOST',2)
NI_NAMEREQD = Constant('NI_NAMEREQD',4)
NI_NUMERICSERV = Constant('NI_NUMERICSERV',8)
NI_DGRAM = Constant('NI_DGRAM',16)
EAI_FAMILY = Constant('EAI_FAMILY',-1)
EAI_SOCKTYPE = Constant('EAI_SOCKTYPE',-2)
EAI_BADFLAGS = Constant('EAI_BADFLAGS',-3)
EAI_NONAME = Constant('EAI_NONAME',-4)
EAI_SERVICE = Constant('EAI_SERVICE',-5)
EAI_ADDRFAMILY = Constant('EAI_ADDRFAMILY',-6)
EAI_NODATA = Constant('EAI_NODATA',-7)
EAI_MEMORY = Constant('EAI_MEMORY',-8)
EAI_FAIL = Constant('EAI_FAIL',-9)
EAI_AGAIN = Constant('EAI_AGAIN',-10)
EAI_SYSTEM = Constant('EAI_SYSTEM',-11)
AI_NUMERICHOST = Constant('AI_NUMERICHOST',1)
AI_CANONNAME = Constant('AI_CANONNAME',2)
AI_PASSIVE = Constant('AI_PASSIVE',4)
SIOCADDRT = Constant('SIOCADDRT',0x890B)
SIOCDELRT = Constant('SIOCDELRT',0x890C)
SIOCRTMSG = Constant('SIOCRTMSG',0x890D)
SIOCGIFNAME = Constant('SIOCGIFNAME',0x8910)
SIOCSIFLINK = Constant('SIOCSIFLINK',0x8911)
SIOCGIFCONF = Constant('SIOCGIFCONF',0x8912)
SIOCGIFFLAGS = Constant('SIOCGIFFLAGS',0x8913)
SIOCSIFFLAGS = Constant('SIOCSIFFLAGS',0x8914)
SIOCGIFADDR = Constant('SIOCGIFADDR',0x8915)
SIOCSIFADDR = Constant('SIOCSIFADDR',0x8916)
SIOCGIFDSTADDR = Constant('SIOCGIFDSTADDR',0x8917)
SIOCSIFDSTADDR = Constant('SIOCSIFDSTADDR',0x8918)
SIOCGIFBRDADDR = Constant('SIOCGIFBRDADDR',0x8919)
SIOCSIFBRDADDR = Constant('SIOCSIFBRDADDR',0x891a)
SIOCGIFNETMASK = Constant('SIOCGIFNETMASK',0x891b)
SIOCSIFNETMASK = Constant('SIOCSIFNETMASK',0x891c)
SIOCGIFMETRIC = Constant('SIOCGIFMETRIC',0x891d)
SIOCSIFMETRIC = Constant('SIOCSIFMETRIC',0x891e)
SIOCGIFMEM = Constant('SIOCGIFMEM',0x891f)
SIOCSIFMEM = Constant('SIOCSIFMEM',0x8920)
SIOCGIFMTU = Constant('SIOCGIFMTU',0x8921)
SIOCSIFMTU = Constant('SIOCSIFMTU',0x8922)
SIOCSIFNAME = Constant('SIOCSIFNAME',0x8923)
SIOCSIFHWADDR = Constant('SIOCSIFHWADDR',0x8924)
SIOCGIFENCAP = Constant('SIOCGIFENCAP',0x8925)
SIOCSIFENCAP = Constant('SIOCSIFENCAP',0x8926)
SIOCGIFHWADDR = Constant('SIOCGIFHWADDR',0x8927)
SIOCGIFSLAVE = Constant('SIOCGIFSLAVE',0x8929)
SIOCSIFSLAVE = Constant('SIOCSIFSLAVE',0x8930)
SIOCADDMULTI = Constant('SIOCADDMULTI',0x8931)
SIOCDELMULTI = Constant('SIOCDELMULTI',0x8932)
SIOCGIFINDEX = Constant('SIOCGIFINDEX',0x8933)
SIOGIFINDEX = Constant('SIOGIFINDEX',0x8933)
SIOCSIFPFLAGS = Constant('SIOCSIFPFLAGS',0x8934)
SIOCGIFPFLAGS = Constant('SIOCGIFPFLAGS',0x8935)
SIOCDIFADDR = Constant('SIOCDIFADDR',0x8936)
SIOCSIFHWBROADCAST = Constant('SIOCSIFHWBROADCAST',0x8937)
SIOCGIFCOUNT = Constant('SIOCGIFCOUNT',0x8938)
SIOCGIFBR = Constant('SIOCGIFBR',0x8940)
SIOCSIFBR = Constant('SIOCSIFBR',0x8941)
SIOCGIFTXQLEN = Constant('SIOCGIFTXQLEN',0x8942)
SIOCSIFTXQLEN = Constant('SIOCSIFTXQLEN',0x8943)
SIOCGIFDIVERT = Constant('SIOCGIFDIVERT',0x8944)
SIOCSIFDIVERT = Constant('SIOCSIFDIVERT',0x8945)
SIOCETHTOOL = Constant('SIOCETHTOOL',0x8946)
SIOCDARP = Constant('SIOCDARP',0x8953)
SIOCGARP = Constant('SIOCGARP',0x8954)
SIOCSARP = Constant('SIOCSARP',0x8955)
SIOCDRARP = Constant('SIOCDRARP',0x8960)
SIOCGRARP = Constant('SIOCGRARP',0x8961)
SIOCSRARP = Constant('SIOCSRARP',0x8962)
SIOCGIFMAP = Constant('SIOCGIFMAP',0x8970)
SIOCSIFMAP = Constant('SIOCSIFMAP',0x8971)
SIOCADDDLCI = Constant('SIOCADDDLCI',0x8980)
SIOCDELDLCI = Constant('SIOCDELDLCI',0x8981)
SIOCDEVPRIVATE = Constant('SIOCDEVPRIVATE',0x89F0)
PTRACE_TRACEME = Constant('PTRACE_TRACEME',0)
PTRACE_PEEKTEXT = Constant('PTRACE_PEEKTEXT',1)
PTRACE_PEEKDATA = Constant('PTRACE_PEEKDATA',2)
PTRACE_PEEKUSR = Constant('PTRACE_PEEKUSR',3)
PTRACE_PEEKUSER = Constant('PTRACE_PEEKUSER',3)
PTRACE_POKETEXT = Constant('PTRACE_POKETEXT',4)
PTRACE_POKEDATA = Constant('PTRACE_POKEDATA',5)
PTRACE_POKEUSR = Constant('PTRACE_POKEUSR',6)
PTRACE_POKEUSER = Constant('PTRACE_POKEUSER',6)
PTRACE_CONT = Constant('PTRACE_CONT',7)
PTRACE_KILL = Constant('PTRACE_KILL',8)
PTRACE_SINGLESTEP = Constant('PTRACE_SINGLESTEP',9)
PTRACE_ATTACH = Constant('PTRACE_ATTACH',0x10)
PTRACE_DETACH = Constant('PTRACE_DETACH',0x11)
PTRACE_SYSCALL = Constant('PTRACE_SYSCALL',24)
PTRACE_GETEVENTMSG = Constant('PTRACE_GETEVENTMSG',0x4201)
PTRACE_GETSIGINFO = Constant('PTRACE_GETSIGINFO',0x4202)
PTRACE_SETSIGINFO = Constant('PTRACE_SETSIGINFO',0x4203)
PTRACE_O_TRACESYSGOOD = Constant('PTRACE_O_TRACESYSGOOD',0x00000001)
PTRACE_O_TRACEFORK = Constant('PTRACE_O_TRACEFORK',0x00000002)
PTRACE_O_TRACEVFORK = Constant('PTRACE_O_TRACEVFORK',0x00000004)
PTRACE_O_TRACECLONE = Constant('PTRACE_O_TRACECLONE',0x00000008)
PTRACE_O_TRACEEXEC = Constant('PTRACE_O_TRACEEXEC',0x00000010)
PTRACE_O_TRACEVFORKDONE = Constant('PTRACE_O_TRACEVFORKDONE',0x00000020)
PTRACE_O_TRACEEXIT = Constant('PTRACE_O_TRACEEXIT',0x00000040)
PTRACE_O_MASK = Constant('PTRACE_O_MASK',0x0000007f)
PTRACE_EVENT_FORK = Constant('PTRACE_EVENT_FORK',1)
PTRACE_EVENT_VFORK = Constant('PTRACE_EVENT_VFORK',2)
PTRACE_EVENT_CLONE = Constant('PTRACE_EVENT_CLONE',3)
PTRACE_EVENT_EXEC = Constant('PTRACE_EVENT_EXEC',4)
PTRACE_EVENT_VFORK_DONE = Constant('PTRACE_EVENT_VFORK_DONE',5)
PTRACE_EVENT_EXIT = Constant('PTRACE_EVENT_EXIT',6)
PT_TRACE_ME = Constant('PT_TRACE_ME',0)
PT_READ_I = Constant('PT_READ_I',1)
PT_READ_D = Constant('PT_READ_D',2)
PT_READ_U = Constant('PT_READ_U',3)
PT_WRITE_I = Constant('PT_WRITE_I',4)
PT_WRITE_D = Constant('PT_WRITE_D',5)
PT_WRITE_U = Constant('PT_WRITE_U',6)
PT_CONTINUE = Constant('PT_CONTINUE',7)
PT_KILL = Constant('PT_KILL',8)
PT_STEP = Constant('PT_STEP',9)
PT_ATTACH = Constant('PT_ATTACH',0x10)
PT_DETACH = Constant('PT_DETACH',0x11)
UREG_G0 = Constant('UREG_G0',0)
UREG_G1 = Constant('UREG_G1',1)
UREG_G2 = Constant('UREG_G2',2)
UREG_G3 = Constant('UREG_G3',3)
UREG_G4 = Constant('UREG_G4',4)
UREG_G5 = Constant('UREG_G5',5)
UREG_G6 = Constant('UREG_G6',6)
UREG_G7 = Constant('UREG_G7',7)
UREG_I0 = Constant('UREG_I0',8)
UREG_I1 = Constant('UREG_I1',9)
UREG_I2 = Constant('UREG_I2',10)
UREG_I3 = Constant('UREG_I3',11)
UREG_I4 = Constant('UREG_I4',12)
UREG_I5 = Constant('UREG_I5',13)
UREG_I6 = Constant('UREG_I6',14)
UREG_I7 = Constant('UREG_I7',15)
UREG_WIM = Constant('UREG_WIM',0)
UREG_FADDR = Constant('UREG_FADDR',0)
UREG_FP = Constant('UREG_FP',14)
UREG_RETPC = Constant('UREG_RETPC',15)
PT_PSR = Constant('PT_PSR',0x0)
PT_PC = Constant('PT_PC',0x4)
PT_NPC = Constant('PT_NPC',0x8)
PT_Y = Constant('PT_Y',0xc)
PT_G0 = Constant('PT_G0',0x10)
PT_WIM = Constant('PT_WIM',0x10)
PT_G1 = Constant('PT_G1',0x14)
PT_G2 = Constant('PT_G2',0x18)
PT_G3 = Constant('PT_G3',0x1c)
PT_G4 = Constant('PT_G4',0x20)
PT_G5 = Constant('PT_G5',0x24)
PT_G6 = Constant('PT_G6',0x28)
PT_G7 = Constant('PT_G7',0x2c)
PT_I0 = Constant('PT_I0',0x30)
PT_I1 = Constant('PT_I1',0x34)
PT_I2 = Constant('PT_I2',0x38)
PT_I3 = Constant('PT_I3',0x3c)
PT_I4 = Constant('PT_I4',0x40)
PT_I5 = Constant('PT_I5',0x44)
PT_I6 = Constant('PT_I6',0x48)
PT_FP = Constant('PT_FP',0x48)
PT_I7 = Constant('PT_I7',0x4c)
RW_L0 = Constant('RW_L0',0x00)
RW_L1 = Constant('RW_L1',0x04)
RW_L2 = Constant('RW_L2',0x08)
RW_L3 = Constant('RW_L3',0x0c)
RW_L4 = Constant('RW_L4',0x10)
RW_L5 = Constant('RW_L5',0x14)
RW_L6 = Constant('RW_L6',0x18)
RW_L7 = Constant('RW_L7',0x1c)
RW_I0 = Constant('RW_I0',0x20)
RW_I1 = Constant('RW_I1',0x24)
RW_I2 = Constant('RW_I2',0x28)
RW_I3 = Constant('RW_I3',0x2c)
RW_I4 = Constant('RW_I4',0x30)
RW_I5 = Constant('RW_I5',0x34)
RW_I6 = Constant('RW_I6',0x38)
RW_I7 = Constant('RW_I7',0x3c)
SF_L0 = Constant('SF_L0',0x00)
SF_L1 = Constant('SF_L1',0x04)
SF_L2 = Constant('SF_L2',0x08)
SF_L3 = Constant('SF_L3',0x0c)
SF_L4 = Constant('SF_L4',0x10)
SF_L5 = Constant('SF_L5',0x14)
SF_L6 = Constant('SF_L6',0x18)
SF_L7 = Constant('SF_L7',0x1c)
SF_I0 = Constant('SF_I0',0x20)
SF_I1 = Constant('SF_I1',0x24)
SF_I2 = Constant('SF_I2',0x28)
SF_I3 = Constant('SF_I3',0x2c)
SF_I4 = Constant('SF_I4',0x30)
SF_I5 = Constant('SF_I5',0x34)
SF_FP = Constant('SF_FP',0x38)
SF_PC = Constant('SF_PC',0x3c)
SF_RETP = Constant('SF_RETP',0x40)
SF_XARG0 = Constant('SF_XARG0',0x44)
SF_XARG1 = Constant('SF_XARG1',0x48)
SF_XARG2 = Constant('SF_XARG2',0x4c)
SF_XARG3 = Constant('SF_XARG3',0x50)
SF_XARG4 = Constant('SF_XARG4',0x54)
SF_XARG5 = Constant('SF_XARG5',0x58)
SF_XXARG = Constant('SF_XXARG',0x5c)
PTRACE_SUNATTACH = Constant('PTRACE_SUNATTACH',10)
PTRACE_SUNDETACH = Constant('PTRACE_SUNDETACH',11)
PTRACE_GETREGS = Constant('PTRACE_GETREGS',12)
PTRACE_SETREGS = Constant('PTRACE_SETREGS',13)
PTRACE_GETFPREGS = Constant('PTRACE_GETFPREGS',14)
PTRACE_SETFPREGS = Constant('PTRACE_SETFPREGS',15)
PTRACE_READDATA = Constant('PTRACE_READDATA',16)
PTRACE_WRITEDATA = Constant('PTRACE_WRITEDATA',17)
PTRACE_READTEXT = Constant('PTRACE_READTEXT',18)
PTRACE_WRITETEXT = Constant('PTRACE_WRITETEXT',19)
PTRACE_GETFPAREGS = Constant('PTRACE_GETFPAREGS',20)
PTRACE_SETFPAREGS = Constant('PTRACE_SETFPAREGS',21)
PTRACE_GETUCODE = Constant('PTRACE_GETUCODE',29)
SYS_accept = Constant('SYS_accept',99)
SYS_access = Constant('SYS_access',33)
SYS_acct = Constant('SYS_acct',51)
SYS_add_key = Constant('SYS_add_key',281)
SYS_adjtimex = Constant('SYS_adjtimex',219)
SYS_afs_syscall = Constant('SYS_afs_syscall',227)
SYS_alarm = Constant('SYS_alarm',27)
SYS_aplib = Constant('SYS_aplib',255)
SYS_bdflush = Constant('SYS_bdflush',225)
SYS_brk = Constant('SYS_brk',17)
SYS_capget = Constant('SYS_capget',21)
SYS_capset = Constant('SYS_capset',22)
SYS_chdir = Constant('SYS_chdir',12)
SYS_chmod = Constant('SYS_chmod',15)
SYS_chown = Constant('SYS_chown',13)
SYS_chown32 = Constant('SYS_chown32',35)
SYS_chroot = Constant('SYS_chroot',61)
SYS_clock_getres = Constant('SYS_clock_getres',258)
SYS_clock_gettime = Constant('SYS_clock_gettime',257)
SYS_clock_nanosleep = Constant('SYS_clock_nanosleep',259)
SYS_clock_settime = Constant('SYS_clock_settime',256)
SYS_clone = Constant('SYS_clone',217)
SYS_close = Constant('SYS_close',6)
SYS_connect = Constant('SYS_connect',98)
SYS_creat = Constant('SYS_creat',8)
SYS_create_module = Constant('SYS_create_module',221)
SYS_delete_module = Constant('SYS_delete_module',222)
SYS_dup = Constant('SYS_dup',41)
SYS_dup2 = Constant('SYS_dup2',90)
SYS_epoll_create = Constant('SYS_epoll_create',193)
SYS_epoll_ctl = Constant('SYS_epoll_ctl',194)
SYS_epoll_pwait = Constant('SYS_epoll_pwait',309)
SYS_epoll_wait = Constant('SYS_epoll_wait',195)
SYS_eventfd = Constant('SYS_eventfd',313)
SYS_execv = Constant('SYS_execv',11)
SYS_execve = Constant('SYS_execve',59)
SYS_exit = Constant('SYS_exit',1)
SYS_exit_group = Constant('SYS_exit_group',188)
SYS_faccessat = Constant('SYS_faccessat',296)
SYS_fadvise64 = Constant('SYS_fadvise64',209)
SYS_fadvise64_64 = Constant('SYS_fadvise64_64',210)
SYS_fallocate = Constant('SYS_fallocate',314)
SYS_fchdir = Constant('SYS_fchdir',176)
SYS_fchmod = Constant('SYS_fchmod',124)
SYS_fchmodat = Constant('SYS_fchmodat',295)
SYS_fchown = Constant('SYS_fchown',123)
SYS_fchown32 = Constant('SYS_fchown32',32)
SYS_fchownat = Constant('SYS_fchownat',287)
SYS_fcntl = Constant('SYS_fcntl',92)
SYS_fcntl64 = Constant('SYS_fcntl64',155)
SYS_fdatasync = Constant('SYS_fdatasync',253)
SYS_fgetxattr = Constant('SYS_fgetxattr',177)
SYS_flistxattr = Constant('SYS_flistxattr',180)
SYS_flock = Constant('SYS_flock',131)
SYS_fork = Constant('SYS_fork',2)
SYS_fremovexattr = Constant('SYS_fremovexattr',186)
SYS_fsetxattr = Constant('SYS_fsetxattr',171)
SYS_fstat = Constant('SYS_fstat',62)
SYS_fstat64 = Constant('SYS_fstat64',63)
SYS_fstatat64 = Constant('SYS_fstatat64',289)
SYS_fstatfs = Constant('SYS_fstatfs',158)
SYS_fstatfs64 = Constant('SYS_fstatfs64',235)
SYS_fsync = Constant('SYS_fsync',95)
SYS_ftruncate = Constant('SYS_ftruncate',130)
SYS_ftruncate64 = Constant('SYS_ftruncate64',84)
SYS_futex = Constant('SYS_futex',142)
SYS_futimesat = Constant('SYS_futimesat',288)
SYS_getcpu = Constant('SYS_getcpu',308)
SYS_getcwd = Constant('SYS_getcwd',119)
SYS_getdents = Constant('SYS_getdents',174)
SYS_getdents64 = Constant('SYS_getdents64',154)
SYS_getdomainname = Constant('SYS_getdomainname',162)
SYS_getegid = Constant('SYS_getegid',50)
SYS_getegid32 = Constant('SYS_getegid32',70)
SYS_geteuid = Constant('SYS_geteuid',49)
SYS_geteuid32 = Constant('SYS_geteuid32',69)
SYS_getgid = Constant('SYS_getgid',47)
SYS_getgid32 = Constant('SYS_getgid32',53)
SYS_getgroups = Constant('SYS_getgroups',79)
SYS_getgroups32 = Constant('SYS_getgroups32',115)
SYS_getitimer = Constant('SYS_getitimer',86)
SYS_get_kernel_syms = Constant('SYS_get_kernel_syms',223)
SYS_get_mempolicy = Constant('SYS_get_mempolicy',304)
SYS_getpagesize = Constant('SYS_getpagesize',64)
SYS_getpeername = Constant('SYS_getpeername',141)
SYS_getpgid = Constant('SYS_getpgid',224)
SYS_getpgrp = Constant('SYS_getpgrp',81)
SYS_getpid = Constant('SYS_getpid',20)
SYS_getppid = Constant('SYS_getppid',197)
SYS_getpriority = Constant('SYS_getpriority',100)
SYS_getresgid32 = Constant('SYS_getresgid32',111)
SYS_getresuid32 = Constant('SYS_getresuid32',109)
SYS_getrlimit = Constant('SYS_getrlimit',144)
SYS_get_robust_list = Constant('SYS_get_robust_list',301)
SYS_getrusage = Constant('SYS_getrusage',117)
SYS_getsid = Constant('SYS_getsid',252)
SYS_getsockname = Constant('SYS_getsockname',150)
SYS_getsockopt = Constant('SYS_getsockopt',118)
SYS_gettid = Constant('SYS_gettid',143)
SYS_gettimeofday = Constant('SYS_gettimeofday',116)
SYS_getuid = Constant('SYS_getuid',24)
SYS_getuid32 = Constant('SYS_getuid32',44)
SYS_getxattr = Constant('SYS_getxattr',172)
SYS_init_module = Constant('SYS_init_module',190)
SYS_io_cancel = Constant('SYS_io_cancel',271)
SYS_ioctl = Constant('SYS_ioctl',54)
SYS_io_destroy = Constant('SYS_io_destroy',269)
SYS_io_getevents = Constant('SYS_io_getevents',272)
SYS_io_setup = Constant('SYS_io_setup',268)
SYS_io_submit = Constant('SYS_io_submit',270)
SYS_ipc = Constant('SYS_ipc',215)
SYS_kexec_load = Constant('SYS_kexec_load',306)
SYS_keyctl = Constant('SYS_keyctl',283)
SYS_kill = Constant('SYS_kill',37)
SYS_lchown = Constant('SYS_lchown',16)
SYS_lchown32 = Constant('SYS_lchown32',31)
SYS_lgetxattr = Constant('SYS_lgetxattr',173)
SYS_link = Constant('SYS_link',9)
SYS_linkat = Constant('SYS_linkat',292)
SYS_listxattr = Constant('SYS_listxattr',178)
SYS_llistxattr = Constant('SYS_llistxattr',179)
SYS__llseek = Constant('SYS__llseek',236)
SYS_lookup_dcookie = Constant('SYS_lookup_dcookie',208)
SYS_lremovexattr = Constant('SYS_lremovexattr',182)
SYS_lseek = Constant('SYS_lseek',19)
SYS_lsetxattr = Constant('SYS_lsetxattr',170)
SYS_lstat = Constant('SYS_lstat',40)
SYS_lstat64 = Constant('SYS_lstat64',132)
SYS_madvise = Constant('SYS_madvise',75)
SYS_mbind = Constant('SYS_mbind',303)
SYS_migrate_pages = Constant('SYS_migrate_pages',302)
SYS_mincore = Constant('SYS_mincore',78)
SYS_mkdir = Constant('SYS_mkdir',136)
SYS_mkdirat = Constant('SYS_mkdirat',285)
SYS_mknod = Constant('SYS_mknod',14)
SYS_mknodat = Constant('SYS_mknodat',286)
SYS_mlock = Constant('SYS_mlock',237)
SYS_mlockall = Constant('SYS_mlockall',239)
SYS_mmap = Constant('SYS_mmap',71)
SYS_mmap2 = Constant('SYS_mmap2',56)
SYS_mount = Constant('SYS_mount',167)
SYS_move_pages = Constant('SYS_move_pages',307)
SYS_mprotect = Constant('SYS_mprotect',74)
SYS_mq_getsetattr = Constant('SYS_mq_getsetattr',278)
SYS_mq_notify = Constant('SYS_mq_notify',277)
SYS_mq_open = Constant('SYS_mq_open',273)
SYS_mq_timedreceive = Constant('SYS_mq_timedreceive',276)
SYS_mq_timedsend = Constant('SYS_mq_timedsend',275)
SYS_mq_unlink = Constant('SYS_mq_unlink',274)
SYS_mremap = Constant('SYS_mremap',250)
SYS_msync = Constant('SYS_msync',65)
SYS_munlock = Constant('SYS_munlock',238)
SYS_munlockall = Constant('SYS_munlockall',240)
SYS_munmap = Constant('SYS_munmap',73)
SYS_nanosleep = Constant('SYS_nanosleep',249)
SYS__newselect = Constant('SYS__newselect',230)
SYS_nfsservctl = Constant('SYS_nfsservctl',254)
SYS_nice = Constant('SYS_nice',34)
SYS_oldlstat = Constant('SYS_oldlstat',202)
SYS_open = Constant('SYS_open',5)
SYS_openat = Constant('SYS_openat',284)
SYS_pause = Constant('SYS_pause',29)
SYS_pciconfig_read = Constant('SYS_pciconfig_read',148)
SYS_pciconfig_write = Constant('SYS_pciconfig_write',149)
SYS_perfctr = Constant('SYS_perfctr',18)
SYS_personality = Constant('SYS_personality',191)
SYS_pipe = Constant('SYS_pipe',42)
SYS_pivot_root = Constant('SYS_pivot_root',146)
SYS_poll = Constant('SYS_poll',153)
SYS_ppoll = Constant('SYS_ppoll',298)
SYS_prctl = Constant('SYS_prctl',147)
SYS_pread = Constant('SYS_pread',67)
SYS_pselect6 = Constant('SYS_pselect6',297)
SYS_ptrace = Constant('SYS_ptrace',26)
SYS_pwrite = Constant('SYS_pwrite',68)
SYS_query_module = Constant('SYS_query_module',184)
SYS_quotactl = Constant('SYS_quotactl',165)
SYS_read = Constant('SYS_read',3)
SYS_readahead = Constant('SYS_readahead',205)
SYS_readdir = Constant('SYS_readdir',204)
SYS_readlink = Constant('SYS_readlink',58)
SYS_readlinkat = Constant('SYS_readlinkat',294)
SYS_readv = Constant('SYS_readv',120)
SYS_reboot = Constant('SYS_reboot',55)
SYS_recvfrom = Constant('SYS_recvfrom',125)
SYS_recvmsg = Constant('SYS_recvmsg',113)
SYS_remap_file_pages = Constant('SYS_remap_file_pages',192)
SYS_removexattr = Constant('SYS_removexattr',181)
SYS_rename = Constant('SYS_rename',128)
SYS_renameat = Constant('SYS_renameat',291)
SYS_request_key = Constant('SYS_request_key',282)
SYS_rmdir = Constant('SYS_rmdir',137)
SYS_rt_sigaction = Constant('SYS_rt_sigaction',102)
SYS_rt_sigpending = Constant('SYS_rt_sigpending',104)
SYS_rt_sigprocmask = Constant('SYS_rt_sigprocmask',103)
SYS_rt_sigqueueinfo = Constant('SYS_rt_sigqueueinfo',106)
SYS_rt_sigreturn = Constant('SYS_rt_sigreturn',101)
SYS_rt_sigsuspend = Constant('SYS_rt_sigsuspend',107)
SYS_rt_sigtimedwait = Constant('SYS_rt_sigtimedwait',105)
SYS_sched_getaffinity = Constant('SYS_sched_getaffinity',260)
SYS_sched_get_affinity = Constant('SYS_sched_get_affinity',161)
SYS_sched_getparam = Constant('SYS_sched_getparam',242)
SYS_sched_get_priority_max = Constant('SYS_sched_get_priority_max',246)
SYS_sched_get_priority_min = Constant('SYS_sched_get_priority_min',247)
SYS_sched_getscheduler = Constant('SYS_sched_getscheduler',244)
SYS_sched_rr_get_interval = Constant('SYS_sched_rr_get_interval',248)
SYS_sched_setaffinity = Constant('SYS_sched_setaffinity',261)
SYS_sched_set_affinity = Constant('SYS_sched_set_affinity',160)
SYS_sched_setparam = Constant('SYS_sched_setparam',241)
SYS_sched_setscheduler = Constant('SYS_sched_setscheduler',243)
SYS_sched_yield = Constant('SYS_sched_yield',245)
SYS_select = Constant('SYS_select',93)
SYS_sendfile = Constant('SYS_sendfile',39)
SYS_sendfile64 = Constant('SYS_sendfile64',140)
SYS_sendmsg = Constant('SYS_sendmsg',114)
SYS_sendto = Constant('SYS_sendto',133)
SYS_setdomainname = Constant('SYS_setdomainname',163)
SYS_setfsgid = Constant('SYS_setfsgid',229)
SYS_setfsgid32 = Constant('SYS_setfsgid32',94)
SYS_setfsuid = Constant('SYS_setfsuid',228)
SYS_setfsuid32 = Constant('SYS_setfsuid32',91)
SYS_setgid = Constant('SYS_setgid',46)
SYS_setgid32 = Constant('SYS_setgid32',89)
SYS_setgroups = Constant('SYS_setgroups',80)
SYS_setgroups32 = Constant('SYS_setgroups32',82)
SYS_sethostname = Constant('SYS_sethostname',88)
SYS_setitimer = Constant('SYS_setitimer',83)
SYS_set_mempolicy = Constant('SYS_set_mempolicy',305)
SYS_setpgid = Constant('SYS_setpgid',185)
SYS_setpriority = Constant('SYS_setpriority',96)
SYS_setregid = Constant('SYS_setregid',127)
SYS_setregid32 = Constant('SYS_setregid32',112)
SYS_setresgid32 = Constant('SYS_setresgid32',110)
SYS_setresuid32 = Constant('SYS_setresuid32',108)
SYS_setreuid = Constant('SYS_setreuid',126)
SYS_setreuid32 = Constant('SYS_setreuid32',72)
SYS_setrlimit = Constant('SYS_setrlimit',145)
SYS_set_robust_list = Constant('SYS_set_robust_list',300)
SYS_setsid = Constant('SYS_setsid',175)
SYS_set_tid_address = Constant('SYS_set_tid_address',166)
SYS_settimeofday = Constant('SYS_settimeofday',122)
SYS_setuid = Constant('SYS_setuid',23)
SYS_setuid32 = Constant('SYS_setuid32',87)
SYS_setxattr = Constant('SYS_setxattr',169)
SYS_sgetmask = Constant('SYS_sgetmask',199)
SYS_shutdown = Constant('SYS_shutdown',134)
SYS_sigaction = Constant('SYS_sigaction',198)
SYS_sigaltstack = Constant('SYS_sigaltstack',28)
SYS_signal = Constant('SYS_signal',48)
SYS_signalfd = Constant('SYS_signalfd',311)
SYS_sigpending = Constant('SYS_sigpending',183)
SYS_sigprocmask = Constant('SYS_sigprocmask',220)
SYS_sigreturn = Constant('SYS_sigreturn',216)
SYS_sigsuspend = Constant('SYS_sigsuspend',201)
SYS_socket = Constant('SYS_socket',97)
SYS_socketcall = Constant('SYS_socketcall',206)
SYS_socketpair = Constant('SYS_socketpair',135)
SYS_ssetmask = Constant('SYS_ssetmask',200)
SYS_stat = Constant('SYS_stat',38)
SYS_stat64 = Constant('SYS_stat64',139)
SYS_statfs = Constant('SYS_statfs',157)
SYS_statfs64 = Constant('SYS_statfs64',234)
SYS_stime = Constant('SYS_stime',233)
SYS_swapoff = Constant('SYS_swapoff',213)
SYS_swapon = Constant('SYS_swapon',85)
SYS_symlink = Constant('SYS_symlink',57)
SYS_symlinkat = Constant('SYS_symlinkat',293)
SYS_sync = Constant('SYS_sync',36)
SYS__sysctl = Constant('SYS__sysctl',251)
SYS_sysfs = Constant('SYS_sysfs',226)
SYS_sysinfo = Constant('SYS_sysinfo',214)
SYS_syslog = Constant('SYS_syslog',207)
SYS_sys_setaltroot = Constant('SYS_sys_setaltroot',280)
SYS_tgkill = Constant('SYS_tgkill',211)
SYS_time = Constant('SYS_time',231)
SYS_timer_create = Constant('SYS_timer_create',266)
SYS_timer_delete = Constant('SYS_timer_delete',265)
SYS_timerfd = Constant('SYS_timerfd',312)
SYS_timerfd_gettime = Constant('SYS_timerfd_gettime',316)
SYS_timerfd_settime = Constant('SYS_timerfd_settime',315)
SYS_timer_getoverrun = Constant('SYS_timer_getoverrun',264)
SYS_timer_gettime = Constant('SYS_timer_gettime',263)
SYS_timer_settime = Constant('SYS_timer_settime',262)
SYS_times = Constant('SYS_times',43)
SYS_tkill = Constant('SYS_tkill',187)
SYS_truncate = Constant('SYS_truncate',129)
SYS_truncate64 = Constant('SYS_truncate64',77)
SYS_umask = Constant('SYS_umask',60)
SYS_umount = Constant('SYS_umount',159)
SYS_umount2 = Constant('SYS_umount2',45)
SYS_uname = Constant('SYS_uname',189)
SYS_unlink = Constant('SYS_unlink',10)
SYS_unlinkat = Constant('SYS_unlinkat',290)
SYS_unshare = Constant('SYS_unshare',299)
SYS_uselib = Constant('SYS_uselib',203)
SYS_ustat = Constant('SYS_ustat',168)
SYS_utime = Constant('SYS_utime',30)
SYS_utimensat = Constant('SYS_utimensat',310)
SYS_utimes = Constant('SYS_utimes',138)
SYS_vfork = Constant('SYS_vfork',66)
SYS_vhangup = Constant('SYS_vhangup',76)
SYS_wait4 = Constant('SYS_wait4',7)
SYS_waitid = Constant('SYS_waitid',279)
SYS_waitpid = Constant('SYS_waitpid',212)
SYS_write = Constant('SYS_write',4)
SYS_writev = Constant('SYS_writev',121)
